@@ -1,8 +1,8 @@
-from PyObjCTools.TestSupport import *
-
 import StoreKit
+from PyObjCTools.TestSupport import TestCase
 
-class TestSKProductDiscount (TestCase):
+
+class TestSKProductDiscount(TestCase):
     def test_constants(self):
         self.assertEqual(StoreKit.SKProductDiscountPaymentModePayAsYouGo, 0)
         self.assertEqual(StoreKit.SKProductDiscountPaymentModePayUpFront, 1)
@@ -10,8 +10,3 @@ class TestSKProductDiscount (TestCase):
 
         self.assertEqual(StoreKit.SKProductDiscountTypeIntroductory, 0)
         self.assertEqual(StoreKit.SKProductDiscountTypeSubscription, 1)
-
-
-if __name__ == "__main__":
-    main()
-
